==> aa_ledger-0.5.8.tar.gz: aa_ledger-0.5.8/ledger/tests/test_api/_ledgerchardata.py <==
noData = [
    {
        "ratting": [],
        "total": {
            "total_amount": "0.00",
            "total_amount_ess": "0.00",
            "total_amount_all": "0.00",
            "total_amount_mining": "0",
            "total_amount_others": "0.00",
            "total_amount_costs": "0.00",
        },
        "billboard": {
            "standard": {
                "walletcharts": None,
                "charts": [],
                "rattingbar": None,
                "workflowgauge": None,
            },
            "weekly": {
                "walletcharts": [],
                "charts": [],
                "rattingbar": [],
                "workflowgauge": [],
            },
            "hourly": {
                "walletcharts": [],
                "charts": [],
                "rattingbar": None,
                "workflowgauge": [],
            },
        },
    }
]

CharmonthlyMarch = [
    {
        "ratting": [
            {
                "main_id": 1001,
                "main_name": "Gneuten",
                "total_amount": "200000.00",
                "total_amount_ess": "1133333.333333333333333333333",
                "total_amount_mining": "200000",
                "total_amount_others": "200000.00",
                "total_amount_costs": "-200000.00",
            }
        ],
        "total": {
            "total_amount": "200000.00",
            "total_amount_ess": "1133333.333333333333333333333",
            "total_amount_all": "1533333.333333333333333333333",
            "total_amount_mining": "200000",
            "total_amount_others": "200000.00",
            "total_amount_costs": "-200000.00",
        },
        "billboard": {
            "standard": {
                "walletcharts": [
                    ["Income", 1200000],
                    ["Market Cost", 200000],
                    ["Production Cost", 200000],
                    ["Misc. Cost", 1400000],
                ],
                "charts": [],
                "rattingbar": [
                    ["x", "2024-03-19", "2024-03-16"],
                    ["Ratting", 200000, 0],
                    ["ESS Payout", 1133333, 0],
                    ["Miscellaneous", 200000, 0],
                    ["Mining", 0, 200000],
                    ["Tick"],
                ],
                "workflowgauge": [
                    ["Ratting", 11.5],
                    ["ESS Payout", 65.3],
                    ["Miscellaneous", 11.5],
                    ["Mining", 11.5],
                ],
            },
            "weekly": {
                "walletcharts": [],
                "charts": [],
                "rattingbar": [],
                "workflowgauge": [],
            },
            "hourly": {
                "walletcharts": [],
                "charts": [],
                "rattingbar": [
                    ["x", "2024-03-19 14:00:00", "2024-03-16 00:00:00"],
                    ["Ratting", 200000, 0],
                    ["ESS Payout", 1133333, 0],
                    ["Miscellaneous", 200000, 0],
                    ["Mining", 0, 200000],
                    ["Tick", 66666, 0],
                ],
                "workflowgauge": [],
            },
        },
    }
]


CharmonthlyMarchMulti = [
    {
        "ratting": [
            {
                "main_id": 1001,
                "main_name": "Gneuten",
                "total_amount": "200000.00",
                "total_amount_ess": "1133333.333333333333333333333",
                "total_amount_mining": "200000",
                "total_amount_others": "200000.00",
                "total_amount_costs": "-200000.00",
            },
            {
                "main_id": 1002,
                "main_name": "rotze Rotineque",
                "total_amount": "0.00",
                "total_amount_ess": "0.00",
                "total_amount_mining": "100000",
                "total_amount_others": "0.00",
                "total_amount_costs": "0.00",
            },
        ],
        "total": {
            "total_amount": "200000.00",
            "total_amount_ess": "1133333.333333333333333333333",
            "total_amount_all": "1633333.333333333333333333333",
            "total_amount_mining": "300000",
            "total_amount_others": "200000.00",
            "total_amount_costs": "-200000.00",
        },
        "billboard": {
            "standard": {
                "walletcharts": [
                    ["Income", 1200000],
                    ["Market Cost", 200000],
                    ["Production Cost", 200000],
                    ["Misc. Cost", 1400000],
                ],
                "charts": [],
                "rattingbar": [
                    ["x", "2024-03-19", "2024-03-16"],
                    ["Ratting", 200000, 0],
                    ["ESS Payout", 1133333, 0],
                    ["Miscellaneous", 200000, 0],
                    ["Mining", 0, 300000],
                    ["Tick"],
                ],
                "workflowgauge": [
                    ["Ratting", 10.9],
                    ["ESS Payout", 61.8],
                    ["Miscellaneous", 10.9],
                    ["Mining", 16.3],
                ],
            },
            "weekly": {
                "walletcharts": [],
                "charts": [],
                "rattingbar": [],
                "workflowgauge": [],
            },
            "hourly": {
                "walletcharts": [],
                "charts": [],
                "rattingbar": [
                    ["x", "2024-03-19 14:00:00", "2024-03-16 00:00:00"],
                    ["Ratting", 200000, 0],
                    ["ESS Payout", 1133333, 0],
                    ["Miscellaneous", 200000, 0],
                    ["Mining", 0, 300000],
                    ["Tick", 66666, 0],
                ],
                "workflowgauge": [],
            },
        },
    }
]

Charyearly = [
    {
        "ratting": [
            {
                "main_id": 1001,
                "main_name": "Gneuten",
                "total_amount": "300000.00",
                "total_amount_ess": "1133333.333333333333333333333",
                "total_amount_mining": "200000",
                "total_amount_others": "200000.00",
                "total_amount_costs": "-200000.00",
            }
        ],
        "total": {
            "total_amount": "300000.00",
            "total_amount_ess": "1133333.333333333333333333333",
            "total_amount_all": "1633333.333333333333333333333",
            "total_amount_mining": "200000",
            "total_amount_others": "200000.00",
            "total_amount_costs": "-200000.00",
        },
        "billboard": {
            "standard": {
                "walletcharts": [
                    ["Income", 700000],
                    ["Market Cost", 100000],
                    ["Production Cost", 100000],
                    ["Misc. Cost", 800000],
                ],
                "charts": [],
                "rattingbar": [
                    ["x", "2024-03", "2024-01"],
                    ["Ratting", 200000, 100000],
                    ["ESS Payout", 1133333, 0],
                    ["Miscellaneous", 200000, 0],
                    ["Mining", 200000, 0],
                    ["Tick"],
                ],
                "workflowgauge": [
                    ["Ratting", 16.3],
                    ["ESS Payout", 61.8],
                    ["Miscellaneous", 10.9],
                    ["Mining", 10.9],
                ],
            },
            "weekly": {
                "walletcharts": [],
                "charts": [],
                "rattingbar": [],
                "workflowgauge": [],
            },
            "hourly": {
                "walletcharts": [],
                "charts": [],
                "rattingbar": [],
                "workflowgauge": [],
            },
        },
    }
]

CharNoMining = [
    {
        "ratting": [
            {
                "main_id": 1001,
                "main_name": "Gneuten",
                "total_amount": "200000.00",
                "total_amount_ess": "1133333.333333333333333333333",
                "total_amount_mining": "0",
                "total_amount_others": "200000.00",
                "total_amount_costs": "-200000.00",
            }
        ],
        "total": {
            "total_amount": "200000.00",
            "total_amount_ess": "1133333.333333333333333333333",
            "total_amount_all": "1333333.333333333333333333333",
            "total_amount_mining": "0",
            "total_amount_others": "200000.00",
            "total_amount_costs": "-200000.00",
        },
        "billboard": {
            "standard": {
                "walletcharts": [
                    ["Income", 1200000],
                    ["Market Cost", 200000],
                    ["Production Cost", 200000],
                    ["Misc. Cost", 1400000],
                ],
                "charts": [],
                "rattingbar": [
                    ["x", "2024-03-19"],
                    ["Ratting", 200000],
                    ["ESS Payout", 1133333],
                    ["Miscellaneous", 200000],
                    ["Mining", 0],
                    ["Tick"],
                ],
                "workflowgauge": [
                    ["Ratting", 13.0],
                    ["ESS Payout", 73.9],
                    ["Miscellaneous", 13.0],
                    ["Mining", 0.0],
                ],
            },
            "weekly": {
                "walletcharts": [],
                "charts": [],
                "rattingbar": [],
                "workflowgauge": [],
            },
            "hourly": {
                "walletcharts": [],
                "charts": [],
                "rattingbar": [
                    ["x", "2024-03-19 14:00:00"],
                    ["Ratting", 200000],
                    ["ESS Payout", 1133333],
                    ["Miscellaneous", 200000],
                    ["Mining", 0],
                    ["Tick", 66666],
                ],
                "workflowgauge": [],
            },
        },
    }
]

==> aa_ledger-0.6.3.tar.gz: aa_ledger-0.6.3/ledger/tests/test_api/_ledgerchardata.py <==
noData = [
    {
        "ratting": [],
        "total": {
            "total_amount": "0",
            "total_amount_ess": "0",
            "total_amount_all": "0",
            "total_amount_mining": "0",
            "total_amount_others": "0",
            "total_amount_costs": "0",
        },
    }
]

CharmonthlyMarch = [
    {
        "ratting": [
            {
                "main_id": 1001,
                "main_name": "Gneuten",
                "total_amount": "200000.00",
                "total_amount_ess": "1133333.333333333333333333333",
                "total_amount_mining": "200000",
                "total_amount_others": "200000.00",
                "total_amount_costs": "-400000.00",
            }
        ],
        "total": {
            "total_amount": "200000.00",
            "total_amount_ess": "1133333.333333333333333333333",
            "total_amount_all": "1333333.333333333333333333333",
            "total_amount_mining": "200000",
            "total_amount_others": "200000.00",
            "total_amount_costs": "-400000.00",
        },
    }
]


CharmonthlyMarchMulti = [
    {
        "ratting": [
            {
                "main_id": 1001,
                "main_name": "Gneuten",
                "total_amount": "200000.00",
                "total_amount_ess": "1133333.333333333333333333333",
                "total_amount_mining": "200000",
                "total_amount_others": "200000.00",
                "total_amount_costs": "-400000.00",
            },
            {
                "main_id": 1002,
                "main_name": "rotze Rotineque",
                "total_amount": "0",
                "total_amount_ess": "0",
                "total_amount_mining": "100000",
                "total_amount_others": "0",
                "total_amount_costs": "0",
            },
        ],
        "total": {
            "total_amount": "200000.00",
            "total_amount_ess": "1133333.333333333333333333333",
            "total_amount_all": "1433333.333333333333333333333",
            "total_amount_mining": "300000",
            "total_amount_others": "200000.00",
            "total_amount_costs": "-400000.00",
        },
    }
]

Charyearly = [
    {
        "ratting": [
            {
                "main_id": 1001,
                "main_name": "Gneuten",
                "total_amount": "300000.00",
                "total_amount_ess": "1133333.333333333333333333333",
                "total_amount_mining": "200000",
                "total_amount_others": "200000.00",
                "total_amount_costs": "-400000.00",
            }
        ],
        "total": {
            "total_amount": "300000.00",
            "total_amount_ess": "1133333.333333333333333333333",
            "total_amount_all": "1433333.333333333333333333333",
            "total_amount_mining": "200000",
            "total_amount_others": "200000.00",
            "total_amount_costs": "-400000.00",
        },
    }
]

CharNoMining = [
    {
        "ratting": [
            {
                "main_id": 1001,
                "main_name": "Gneuten",
                "total_amount": "200000.00",
                "total_amount_ess": "1133333.333333333333333333333",
                "total_amount_mining": "0",
                "total_amount_others": "200000.00",
                "total_amount_costs": "-400000.00",
            }
        ],
        "total": {
            "total_amount": "200000.00",
            "total_amount_ess": "1133333.333333333333333333333",
            "total_amount_all": "1133333.333333333333333333333",
            "total_amount_mining": "0",
            "total_amount_others": "200000.00",
            "total_amount_costs": "-400000.00",
        },
    }
]
